
onnx.shape_inference
====================

.. contents::
    :local:

infer_shapes
++++++++++++

.. autofunction:: onnx.shape_inference.infer_shapes

infer_shapes_path
+++++++++++++++++

.. autofunction:: onnx.shape_inference.infer_shapes_path
